package
Version:
v0.0.0-...-7e478f4
Opens a new window with list of versions in this module.
Published: Aug 22, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Task struct {
Id uint `json:"id" gorm:"primaryKey"`
Task string `json:"task"`
Status string `json:"status"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.